package org.alltimeflashdreamer.log4jmonitor;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * Title: AboutDialog<br>
 * Description: Shows a simple JDialog containing some information about Log4JMonitor.
 * <br>
 * License: GNU Public License 2.0+<br>
 * Organization: All Time Flash Dreamer
 *
 * @author    Copyright (c) 2002 by <a href="mailto:florian@steinsiepe.ch">Florian
 *      Steinsiepe</a>
 * @version   1.1
 */

public class AboutDialog extends JDialog
{
    private final static String ABOUTTEXT = new StringBuffer( Log4JMonitor.TITLE ).append( " is based on " )
            .append( " Apache's demonstration of a SocketServer/SocketAppender pair, programmed by Oliver Burn.\n\n" )
            .append( "The first revision was done by Sven Mosimann, Adrian Seiler and Florian Steinsiepe to be " )
            .append( "used within EcoLogic GmbH, Zrich, Switzerland. This revision included the implementation " )
            .append( "of the Kunststoff look'n'feel and a SocketAppender within Log4JMonitor.\n\n" )
            .append( "The second revision was done by Florian Steinsiepe and included the coloring of the different " )
            .append( "log levels as well as the menu bar and its actions, the documentation and " )
            .append( "the releasing under GPL.\n\n" )
			.append( "The third revision was done by Florian Steinsiepe and included the update of the core classes " )
			.append( "from Apache's Log4j v.1.1.3 to v1.2.5 as well as the solution of the application icon problem, " )
			.append( "which now is loaded from the jar file directly or from the extracted files." ).toString();
    private JLabel jlTitle = new JLabel();
    private JTextArea jtaText = new JTextArea();

    /**
     * Constructs a simple dialog.
     *
     * @param parent  the caller of this class, necessary for error message option
     *      panes
     */
    public AboutDialog( Log4JMonitor parent )
    {
        try
        {
            jbInit();
            this.show();
        } catch ( Exception ex )
        {
            JOptionPane.showMessageDialog( parent, ex.getClass().getName() + "\n" +
                    ex.getMessage(), "Error in AboutDialog", JOptionPane.ERROR_MESSAGE );
        }
    }

    /**
     * Builds up the GUI.
     *
     * @throws Exception  wraps each possible exception
     */
    private void jbInit()
        throws Exception
    {
        this.setSize( 400, 380 );
        this.setResizable( false );
        this.setTitle( "About " + Log4JMonitor.TITLE + "..." );
        GridBagLayout gridbagLayout = new GridBagLayout();
        this.getContentPane().setLayout( gridbagLayout );
        this.setModal( true );
        this.addWindowListener(
            new WindowAdapter()
            {
                public void windowClosed( WindowEvent e )
                {
                    dispose();
                }
            } );

        jlTitle.setFont( new Font( "Dialog", Font.BOLD, 16 ) );
        jlTitle.setHorizontalAlignment( SwingConstants.CENTER );
        jlTitle.setHorizontalTextPosition( SwingConstants.CENTER );
        jlTitle.setText( Log4JMonitor.TITLE + " " + Log4JMonitor.VERSION );
        jlTitle.setSize( 400, 70 );

        jtaText.setBackground( Color.white );
        jtaText.setFont( new Font( "Dialog", Font.PLAIN, 12 ) );
        jtaText.setWrapStyleWord( true );
        jtaText.setEditable( false );
        jtaText.setLineWrap( true );
        jtaText.setTabSize( 4 );
        jtaText.setText( ABOUTTEXT );

        this.getContentPane().add( jlTitle, new GridBagConstraints( 0, 0, 1, 1, 1.0, 0.2
                , GridBagConstraints.CENTER, GridBagConstraints.BOTH, new Insets( 2, 5, 2, 5 ), 0, 0 ) );
        JScrollPane jsp = new JScrollPane( jtaText );
        jsp.setSize( 400, 230 );
        this.getContentPane().add( jsp, new GridBagConstraints( 0, 1, 1, 1, 1.0, 0.8
                , GridBagConstraints.CENTER, GridBagConstraints.BOTH, new Insets( 2, 5, 2, 5 ), 0, 0 ) );
    }
}
