package org.alltimeflashdreamer.log4jmonitor;

import java.awt.Dimension;
import java.awt.Font;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;
import org.apache.log4j.Logger;
import org.apache.log4j.Level;

/**
 * Title: ControlPanel<br>
 * Description: This class initializes the controls for filtering, pausing, exiting,
 * etc.<br>
 * This code has been copied from the authors below.
 *
 * @author    <a href="mailto:chainsaw@puppycrawl.com">Oliver Burn</a> , revised
 *      by <a href="mailto:florian@steinsiepe.ch">Florian Steinsiepe</a>
 * @version   1.1
 */

class ControlPanel extends JPanel
{
    /** use the log messages * */
    private final static Logger LOG = Logger.getLogger( ControlPanel.class );
    private static final Level[] ALLLEVELS =
			new Level[] { Level.DEBUG, Level.INFO, Level.WARN, Level.ERROR, Level.FATAL, Level.OFF };
	/** the button which allows to pause and resume the receiving of LoggingEvents */
	final JButton toggleButton;
	/** the button which allows to clear the contents of the LoggingEvents table */
	final JButton clearButton;

    /**
     * Creates a new <code>ControlPanel</code> instance.
     *
     * @param model  the model for the control panel
     */
    ControlPanel( final MyTableModel model )
    {
        setBorder( BorderFactory.createTitledBorder( "Controls: " ) );
        final GridBagLayout gridbag = new GridBagLayout();
        final GridBagConstraints c = new GridBagConstraints();
        setLayout( gridbag );

        // Pad and inset everything
        c.ipadx = 5;
        c.ipady = 5;
        c.insets = new Insets( 2, 5, 2, 5 );

        // Add the 1st column of labels
        c.gridx = 0;
        c.anchor = GridBagConstraints.EAST;

        c.gridy = 0;
        JLabel label = new JLabel( "Filter Thread:" );
        gridbag.setConstraints( label, c );
        add( label );

        c.gridy++;
        label = new JLabel( "Filter Message:" );
        gridbag.setConstraints( label, c );
        add( label );

        c.gridy++;
        label = new JLabel( "Filter Logger:" );
        gridbag.setConstraints( label, c );
        add( label );

        // Add the 2nd column of filters
        c.weightx = 1;
        //c.weighty = 1;
        c.gridx = 1;
        c.anchor = GridBagConstraints.WEST;
        c.fill = GridBagConstraints.HORIZONTAL;
        c.gridy = 0;
        final JTextField threadField = new JTextField( "" );
        threadField.getDocument().addDocumentListener(
            new DocumentListener()
            {
                public void insertUpdate( DocumentEvent aEvent )
                {
                    model.setThreadFilter( threadField.getText() );
                }

                public void removeUpdate( DocumentEvent aEvente )
                {
                    model.setThreadFilter( threadField.getText() );
                }

                public void changedUpdate( DocumentEvent aEvent )
                {
                    model.setThreadFilter( threadField.getText() );
                }
            } );
        gridbag.setConstraints( threadField, c );
        add( threadField );

        c.gridy++;
        c.gridwidth = 3;

        final JTextField msgField = new JTextField( "" );
        msgField.getDocument().addDocumentListener(
            new DocumentListener()
            {
                public void insertUpdate( DocumentEvent aEvent )
                {
                    model.setMessageFilter( msgField.getText() );
                }

                public void removeUpdate( DocumentEvent aEvent )
                {
                    model.setMessageFilter( msgField.getText() );
                }

                public void changedUpdate( DocumentEvent aEvent )
                {
                    model.setMessageFilter( msgField.getText() );
                }
            } );

        gridbag.setConstraints( msgField, c );
        add( msgField );

        c.gridy++;
        c.gridwidth = 1;
        final JTextField logField = new JTextField( "" );
        logField.getDocument().addDocumentListener(
            new DocumentListener()
            {
                public void insertUpdate( DocumentEvent aEvent )
                {
                    model.setLoggerFilter( logField.getText() );
                }

                public void removeUpdate( DocumentEvent aEvent )
                {
                    model.setLoggerFilter( logField.getText() );
                }

                public void changedUpdate( DocumentEvent aEvent )
                {
                    model.setLoggerFilter( logField.getText() );
                }
            } );
        gridbag.setConstraints( logField, c );
        add( logField );

        // Add the 3rd column of buttons
        c.weightx = 0;
        c.fill = GridBagConstraints.HORIZONTAL;
        c.anchor = GridBagConstraints.EAST;
        c.gridx = 2;

        c.gridy = 0;

        label = new JLabel( "Filter Level:" );
        gridbag.setConstraints( label, c );
        add( label );

        /*
         * c.gridy = 0;
         * final JButton exitButton = new JButton("Exit");
         * exitButton.setMnemonic('x');
         * exitButton.addActionListener(new ActionListener() {
         * public void actionPerformed(ActionEvent aEvent) {
         * LOG.info("shutting down the system");
         * System.exit(0);
         * }
         * });
         * gridbag.setConstraints(exitButton, c);
         * add(exitButton);
         */
        c.gridy++;
        //skip the next row
        c.gridy++;

        clearButton = new JButton( "Clear" );
        clearButton.setMnemonic( 'l' );
        clearButton.addActionListener(
            new ActionListener()
            {
                public void actionPerformed( ActionEvent aEvent )
                {
                    model.clear();
                }
            } );
        clearButton.setMargin( new Insets( 0, 2, 0, 2 ) );
        gridbag.setConstraints( clearButton, c );
        add( clearButton );

        // Add the 4th column of fields
        c.weightx = 0;
        c.fill = GridBagConstraints.HORIZONTAL;
        c.anchor = GridBagConstraints.EAST;
        c.gridx = 3;

        c.gridy = 0;
        final JComboBox levels = new JComboBox( ALLLEVELS );
        final Level lowest = ALLLEVELS[0];
        levels.setSelectedItem( lowest );
        model.setLevelFilter( lowest );
        gridbag.setConstraints( levels, c );
        add( levels );
        levels.setEditable( false );
        levels.addActionListener(
            new ActionListener()
            {
                public void actionPerformed( ActionEvent aEvent )
                {
                    model.setLevelFilter( ( Level )levels.getSelectedItem() );
                }
            } );

        c.gridy++;
        //skip the next row
        c.gridy++;

        toggleButton = new JButton( "Pause" );
        toggleButton.setMnemonic( 'p' );
        toggleButton.addActionListener(
            new ActionListener()
            {
                public void actionPerformed( ActionEvent aEvent )
                {
                    model.toggle();
                    toggleButton.setText( model.isPaused() ? "Resume" : "Pause" );
                }
            } );
        gridbag.setConstraints( toggleButton, c );
        toggleButton.setMargin( new Insets( 0, 2, 0, 2 ) );
        add( toggleButton );
    }
}
